Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(236)

Unified Diff: environs/tools.go

Issue 8726044: environs: use new tool-finding funcs
Patch Set: environs: use new tool-finding funcs Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « environs/openstack/provider.go ('k') | environs/tools_test.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: environs/tools.go
=== modified file 'environs/tools.go'
--- environs/tools.go 2013-04-17 05:14:05 +0000
+++ environs/tools.go 2013-04-17 06:39:43 +0000
@@ -129,13 +129,13 @@
return list, err
}
// EnsureAgentVersion returns a ToolsList containing only those tools with
// which it would be reasonable to launch an environment's first machine,
// given the supplied constraints.
// If the environment was not already configured to use a specific agent
// version, the newest available version will be chosen and set in the
// environment's configuration.
-func EnsureAgentVersion(environ Environ, cons constraints.Value) (list tools.List, err error) {
+func FindBootstrapTools(environ Environ, cons constraints.Value) (list tools.List, err error) {
defer convertToolsError(&err)
// Collect all possible compatible tools.
cliVersion := version.Current.Number
@@ -129,13 +129,13 @@
return list, err
}
-// EnsureAgentVersion returns a ToolsList containing only those tools with
+// FindBootstrapTools returns a ToolsList containing only those tools with
// which it would be reasonable to launch an environment's first machine,
// given the supplied constraints.
« no previous file with comments | « environs/openstack/provider.go ('k') | environs/tools_test.go » ('j') | no next file with comments »

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b